@@ -10,17 +10,24 @@ from Products.CMFCore.utils import getToolByName
 from Products.CMFPlone.utils import getFSVersionTuple
 
 def install(self, reinstall=False):
+
+    
+    mtool = getToolByName(self, 'portal_migration')
+    plone_version = mtool.getFileSystemVersion()
+    if plone_version.startswith('3.0'):
+        version = '3.0'
+    elif plone_version.startswith('3.1'):
+        version = '3.1'
+    else:
+        raise RuntimeError('Unsupported Plone version %s' % plone_version)
+
     tool=getToolByName(self, "portal_setup")
 
-    if getFSVersionTuple()[0]>=3:
+    if version == '3.0':
         tool.runAllImportStepsFromProfile(
                 "profile-Products.SmartPrintNG:smartprintng",
                 purge_old=False)
     else:
-        plone_base_profileid = "profile-CMFPlone:plone"
-        tool.setImportContext(plone_base_profileid)
-        tool.setImportContext("profile-Products.SmartPrintNG:plone25")
-        tool.runAllImportSteps(purge_old=False)
-        tool.setImportContext(plone_base_profileid)
-
-
+        tool.runAllImportStepsFromProfile(
+                "profile-Products.SmartPrintNG:default",
+                purge_old=False)
